=== added file '.bzrignore'
--- .bzrignore	1970-01-01 00:00:00 +0000
+++ .bzrignore	2012-05-15 18:53:11 +0000
@@ -0,0 +1,7 @@
+__pycache__/
+build/
+dist/
+*.egg-info/
+
+MANIFEST
+

=== modified file 'COPYING'
--- COPYING	2009-08-28 18:58:58 +0000
+++ COPYING	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 The MIT License
 
 Copyright (c) 2007 Leah Culver
-Copyright (c) 2009 Canonical, Ltd.
+Copyright (c) 2009-2012 Canonical, Ltd.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal

=== modified file 'MANIFEST.in'
--- MANIFEST.in	2009-08-31 14:26:36 +0000
+++ MANIFEST.in	2012-05-15 18:53:11 +0000
@@ -1,1 +1,2 @@
 include COPYING README
+include run-tests

=== modified file 'poauth/client.py'
--- poauth/client.py	2009-08-31 18:54:22 +0000
+++ poauth/client.py	2012-05-15 18:53:11 +0000
@@ -24,35 +24,46 @@
 OAuth Client interface
 '''
 import random
-import urllib
-import urlparse
+
+quoteurl = None
+parseurl = None
+try:
+    import urllib.parse
+    quoteurl = urllib.parse.quote
+    parseurl = urllib.parse.urlparse
+except ImportError:
+    import urllib
+    import urlparse
+    quoteurl = urllib.quote
+    parseurl = urlparse.urlparse
 
 from warnings import warn
 
+
 def escape(s):
     '''Escape a URL including any /.'''
-    return urllib.quote(s, safe='~')
+    return quoteurl(s, safe='~')
+
 
 def generate_nonce(length=8):
     '''Generate pseudorandom number.'''
     return ''.join([str(random.randint(0, 9)) for i in range(length)])
 
+
 def _utf8_str(s):
     """Convert unicode to utf-8."""
-    if isinstance(s, unicode):
-        return s.encode("utf-8")
-    else:
-        return str(s)
+    return s.encode("utf-8")
+
 
 class OAuthRequest(object):
     '''OAuthRequest represents the request and can be serialized.
 
     OAuth parameters:
-        - oauth_consumer_key 
+        - oauth_consumer_key
         - oauth_token
         - oauth_signature_method
-        - oauth_signature 
-        - oauth_timestamp 
+        - oauth_signature
+        - oauth_timestamp
         - oauth_nonce
         - oauth_version
         ... any additional parameters, as defined by the Service Provider.
@@ -77,7 +88,7 @@
             self.parameters['oauth_verifier'] = self.verifier
         if self.callback:
             self.parameters['oauth_callback'] = self.callback
-        
+
     def set_parameter(self, parameter, value):
         self.parameters[parameter] = value
 
@@ -98,7 +109,7 @@
             pass
         # Escape key values before sorting.
         key_values = [(escape(_utf8_str(k)), escape(_utf8_str(v))) \
-            for k,v in params.items()]
+            for k, v in list(params.items())]
         # Sort lexicographically, first after key, then after value.
         key_values.sort()
         # Combine key value pairs into a string.
@@ -110,7 +121,7 @@
 
     def get_normalized_http_url(self):
         """Parses the URL and rebuilds it to be scheme://host/path."""
-        parts = urlparse.urlparse(self.http_url)
+        parts = parseurl(self.http_url)
         scheme, netloc, path = parts[:3]
         # Exclude default port numbers.
         if scheme == 'http' and netloc[-3:] == ':80':
@@ -135,7 +146,7 @@
         auth_header = 'OAuth realm="%s"' % realm
         # Add the oauth parameters.
         if self.parameters:
-            for k, v in self.parameters.iteritems():
+            for k, v in list(self.parameters.items()):
                 if k.startswith('oauth_'):
                     auth_header += ', %s="%s"' % (k, escape(str(v)))
         return {'Authorization': auth_header}
@@ -143,7 +154,7 @@
     def to_postdata(self):
         """Serialize as post data for a POST request."""
         return '&'.join(['%s=%s' % (escape(str(k)), escape(str(v))) \
-            for k, v in self.parameters.iteritems()])
+            for k, v in list(self.parameters.items())])
 
     def to_url(self):
         """Serialize as a URL for a GET request."""
@@ -193,7 +204,6 @@
         return OAuthRequest(token=token, *args, **newargs)
 
 
-
 class OAuthClient(object):
     '''OAuthClient is a worker to attempt to execute a request.'''
 

=== modified file 'poauth/oauth.py'
--- poauth/oauth.py	2009-09-24 14:54:57 +0000
+++ poauth/oauth.py	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 # The MIT License
 #
 # Copyright (c) 2007 Leah Culver
-# Copyright (c) 2009 Canonical, Ltd.
+# Copyright (c) 2009-2012 Canonical, Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,13 +20,18 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-'''
-OAuth common interface
-'''
+"""OAuth common interface."""
 import binascii
 import cgi
 import hmac
-import urllib
+
+encodeurl = None
+try:
+    from urllib.parse import urlencode
+    encodeurl = urlencode
+except ImportError:
+    import urllib
+    encodeurl = urllib.urlencode
 
 # For compatibility
 from poauth import client
@@ -45,6 +50,7 @@
         self.key = key
         self.secret = secret
 
+
 class OAuthToken(object):
     '''
     OAuthToken is the data type for storing the token in memory.
@@ -59,9 +65,9 @@
         '''
         Returns a form encoded string with the token and secret
         '''
-        return urllib.urlencode({'oauth_token': self.key,
-                                 'oauth_token_secret': self.secret})
- 
+        return encodeurl({'oauth_token': self.key,
+                          'oauth_token_secret': self.secret})
+
     @staticmethod
     def from_string(s):
         '''
@@ -71,8 +77,8 @@
         params = cgi.parse_qs(s, keep_blank_values=False)
         key = params['oauth_token'][0]
         secret = params['oauth_token_secret'][0]
-        verifier = params.get('oauth_verifier', [None])[0]
-        callback = params.get('oauth_callback', [None])[0]
+        # verifier = params.get('oauth_verifier', [None])[0]
+        # callback = params.get('oauth_callback', [None])[0]
         return OAuthToken(key, secret)
 
     def __str__(self):
@@ -86,7 +92,8 @@
         """-> str."""
         raise NotImplementedError
 
-    def build_signature_base_string(self, oauth_request, oauth_consumer, oauth_token):
+    def build_signature_base_string(self, oauth_request,
+                                    oauth_consumer, oauth_token):
         """-> str key, str raw."""
         raise NotImplementedError
 
@@ -104,7 +111,7 @@
 
     def get_name(self):
         return 'HMAC-SHA1'
-        
+
     def build_signature_base_string(self, oauth_request, consumer, token):
         sig = (
             escape(oauth_request.get_normalized_http_method()),
@@ -125,10 +132,11 @@
 
         # HMAC object.
         try:
-            import hashlib # 2.5
-            hashed = hmac.new(key, raw, hashlib.sha1)
+            import hashlib  # 2.5
+            hashed = hmac.new(bytes(key.encode('ascii')),
+                              bytes(raw.encode('ascii')), hashlib.sha1)
         except:
-            import sha # Deprecated
+            import sha  # Deprecated
             hashed = hmac.new(key, raw, sha)
         return hashed.digest()
 

=== modified file 'poauth/server.py'
--- poauth/server.py	2009-09-02 14:20:00 +0000
+++ poauth/server.py	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 # The MIT License
 #
 # Copyright (c) 2007 Leah Culver
-# Copyright (c) 2009 Canonical, Ltd.
+# Copyright (c) 2009-2012 Canonical, Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -20,14 +20,12 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
-'''
-OAuth Server interface
-'''
-import urlparse
+"""OAuth Server interface."""
 
 from poauth.client import OAuthRequest
 from poauth.oauth import OAuthToken, OAUTH_VERSION
 
+
 class OAuthResponse(OAuthRequest):
     '''Class to manage OAuthServer response data.'''
 
@@ -38,12 +36,12 @@
         self.realm = kwargs.get('realm', None)
         self.header = {}
         if self.status_code != 200:
-            self.header = {'WWW-Authenticate' : 'OAuth realm="%s"' % self.realm}
+            self.header = {'WWW-Authenticate': 'OAuth realm="%s"' % self.realm}
 
         self.callback = kwargs.pop('callback', None)
         if self.callback:
             self.status_code = 307
-            self.header = {'Location' : self.callback}
+            self.header = {'Location': self.callback}
 
         self.parameters = kwargs.get('parameters', {})
         try:
@@ -55,7 +53,7 @@
     def headers(self):
         '''Return the set of headers to respond with.'''
         return self.header
-        
+
 
 class OAuthServer(object):
     '''Class for building an OAuth server.'''
@@ -80,7 +78,7 @@
                            'oauth_timestamp',
                            'oauth_nonce',
                            'oauth_callback']
-        supported_params = ['oauth_version']
+        # supported_params = ['oauth_version']
 
         bad_request = OAuthResponse(status=400, message="Bad Request",
                                     realm=self.realm)
@@ -100,7 +98,7 @@
             response_params['oauth_callback_confirmed'] = 'true'
         else:
             try:
-                parts = urlparse.urlparse(callback)
+                # parts = urlparse.urlparse(callback)
                 response_params['oauth_callback_confirmed'] = 'true'
             except:
                 return bad_request
@@ -142,7 +140,7 @@
                            'oauth_timestamp',
                            'oauth_nonce',
                            'oauth_verifier']
-        supported_params = ['oauth_version']
+        # supported_params = ['oauth_version']
 
         parameters = request.parameters
 
@@ -174,9 +172,7 @@
     def __validate_required_params(self, required_params, parameters):
         '''Validate that all the required parameters are there.'''
         for param in required_params:
-            try:
-                exists = parameters[param]
-            except KeyError:
+            if parameters.get(param, None) is None:
                 return False
         return True
 

=== modified file 'poauth/tests/test_client.py'
--- poauth/tests/test_client.py	2009-08-31 18:54:22 +0000
+++ poauth/tests/test_client.py	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 #
 # The MIT License
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,7 @@
 from poauth.oauth import OAuthConsumer, OAuthToken
 from poauth.client import OAuthRequest
 
+
 class OAuthRequestTests(unittest.TestCase):
     '''Tests for OAuthRequest'''
 

=== modified file 'poauth/tests/test_oauth.py'
--- poauth/tests/test_oauth.py	2009-09-24 14:54:57 +0000
+++ poauth/tests/test_oauth.py	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 #
 # The MIT License
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,6 +27,7 @@
 from poauth import oauth
 from poauth.client import OAuthRequest
 
+
 class OAuthSignatureTests(unittest.TestCase):
     '''Tests for OAuthSignatureMethod'''
 
@@ -37,15 +38,16 @@
                                     http_url='http://example.com/request',
                                     consumer=self.consumer,
                                     callback='oob')
+
     def test_PLAINTEXT(self):
         '''Test the PLAINTEXT signature method.'''
         method = oauth.OAuthSignatureMethod_PLAINTEXT()
-        self.assertEquals('PLAINTEXT', method.get_name())
+        self.assertEqual('PLAINTEXT', method.get_name())
         self.request.sign_request(method, self.consumer, None)
-        self.assertEquals(self.request.get_parameter('oauth_signature_method'),
-                          'PLAINTEXT')
+        self.assertEqual(self.request.get_parameter('oauth_signature_method'),
+                         'PLAINTEXT')
         signature = self.request.get_parameter('oauth_signature')
-        self.assertEquals('secret&', signature)
+        self.assertEqual('secret&', signature)
         self.assertTrue(method.check_signature(self.request,
                                                self.consumer, None,
                                                signature))
@@ -53,10 +55,10 @@
     def test_HMACSHA1(self):
         '''Test the HMAC-SHA1 signature method.'''
         method = oauth.OAuthSignatureMethod_HMAC_SHA1()
-        self.assertEquals('HMAC-SHA1', method.get_name())
+        self.assertEqual('HMAC-SHA1', method.get_name())
         self.request.sign_request(method, self.consumer, None)
-        self.assertEquals(self.request.get_parameter('oauth_signature_method'),
-                          'HMAC-SHA1')
+        self.assertEqual(self.request.get_parameter('oauth_signature_method'),
+                         'HMAC-SHA1')
         signature = self.request.get_parameter('oauth_signature')
         self.assertTrue(method.check_signature(self.request,
                                                self.consumer, None,
@@ -64,9 +66,9 @@
         import binascii
         digest = method._build_digest(self.request, self.consumer, None)
 
-        self.assertEquals(digest, binascii.a2b_base64(signature))
+        self.assertEqual(digest, binascii.a2b_base64(signature))
 
     def test_RSASHA1(self):
         '''Test the RSA-SHA1 signature method.'''
         method = oauth.OAuthSignatureMethod_RSA_SHA1()
-        self.assertEquals('RSA-SHA1', method.get_name())
+        self.assertEqual('RSA-SHA1', method.get_name())

=== modified file 'poauth/tests/test_server.py'
--- poauth/tests/test_server.py	2009-09-02 14:20:00 +0000
+++ poauth/tests/test_server.py	2012-05-15 18:53:11 +0000
@@ -1,7 +1,7 @@
 #
 # The MIT License
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -29,6 +29,7 @@
 from poauth.client import OAuthRequest
 from poauth.server import OAuthServer, OAuthStorage, OAuthResponse
 
+
 class FakeOAuthStorage(OAuthStorage):
     '''Fake storage for testing.'''
 
@@ -57,8 +58,8 @@
 
     def fetch_request_token(self, parameters):
         '''Get a request token.'''
-        response_params = {'oauth_token' : self.request_token.key,
-                           'oauth_token_secret' : self.request_token.secret,
+        response_params = {'oauth_token': self.request_token.key,
+                           'oauth_token_secret': self.request_token.secret,
                            }
 
         if parameters['oauth_nonce'] != self.nonce:
@@ -71,8 +72,8 @@
 
     def authorize_request_token(self, token, parameters):
         '''Authorize the token.'''
-        response_params = {'oauth_token' : self.request_token.key,
-                           'oauth_verifier' : self.verifier,
+        response_params = {'oauth_token': self.request_token.key,
+                           'oauth_verifier': self.verifier,
                            }
         if parameters['oauth_token'] == self.request_token.key:
             return OAuthResponse(status=200, parameters=response_params)
@@ -80,8 +81,8 @@
 
     def fetch_access_token(self, token, parameters):
         '''Fetch the access token.'''
-        response_params = {'oauth_token' : self.access_token.key,
-                           'oauth_token_secret' : self.access_token.secret,
+        response_params = {'oauth_token': self.access_token.key,
+                           'oauth_token_secret': self.access_token.secret,
                            }
         verifier = parameters.get('oauth_verifier', self.verifier)
         if verifier == self.verifier:
@@ -104,9 +105,9 @@
 
     def test_get_request_token(self):
         '''Test the creation of a request token.'''
-        request_params = {'oauth_timestamp' : str(int(time.time())),
-                          'oauth_nonce' : 'nonce',
-                          'oauth_version' : oauth.OAUTH_VERSION,
+        request_params = {'oauth_timestamp': str(int(time.time())),
+                          'oauth_nonce': 'nonce',
+                          'oauth_version': oauth.OAUTH_VERSION,
                           }
         request = OAuthRequest(callback="oob", consumer=self.consumer,
                                parameters=request_params)
@@ -114,9 +115,9 @@
         request.sign_request(method, self.consumer, None)
         response = self.server.get_request_token(request)
         self.assertTrue(isinstance(response, OAuthResponse))
-        self.assertEquals(response.status_code, 200)
-        self.assertEquals(response.parameters['oauth_callback_confirmed'],
-                          'true')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.parameters['oauth_callback_confirmed'],
+                         'true')
 
     def test_authorize_request_token(self):
         '''Test authorizing the request token.'''
@@ -124,25 +125,26 @@
         request = OAuthRequest(token=token)
         response = self.server.authorize_request_token(request)
         self.assertTrue(isinstance(response, OAuthResponse))
-        self.assertEquals(response.status_code, 200)
+        self.assertEqual(response.status_code, 200)
 
     def test_get_access_token(self):
         '''Test getting an access token.'''
-        request_params = {'oauth_timestamp' : str(int(time.time())),
-                          'oauth_nonce' : 'nonce',
-                          'oauth_version' : oauth.OAUTH_VERSION,
+        request_params = {'oauth_timestamp': str(int(time.time())),
+                          'oauth_nonce': 'nonce',
+                          'oauth_version': oauth.OAUTH_VERSION,
                           }
         token = oauth.OAuthToken('request_key', 'request_secret',
                                  verifier='verifier')
-        request=OAuthRequest(consumer=self.consumer, token=token,
-                             parameters=request_params)
+        request = OAuthRequest(consumer=self.consumer, token=token,
+                               parameters=request_params)
         method = oauth.OAuthSignatureMethod_PLAINTEXT()
         request.sign_request(method, self.consumer, token)
         response = self.server.get_access_token(request)
         self.assertTrue(isinstance(response, OAuthResponse))
-        self.assertEquals(response.status_code, 200)
-        self.assertEquals(response.token.key, 'access_key')
-        self.assertEquals(response.token.secret, 'access_secret')
+        self.assertEqual(response.status_code, 200)
+        self.assertEqual(response.token.key, 'access_key')
+        self.assertEqual(response.token.secret, 'access_secret')
+
 
 class OAuthStorageTests(unittest.TestCase):
     '''Test the OAuthStorage class.'''
@@ -155,34 +157,34 @@
         '''Test consumer validation.'''
         consumer = self.storage.lookup_consumer('consumer_key')
         self.assertTrue(isinstance(consumer, oauth.OAuthConsumer))
-        self.assertEquals('consumer_key', consumer.key)
+        self.assertEqual('consumer_key', consumer.key)
 
     def test_fetch_request_token(self):
         '''Test fetching the request token.'''
-        parameters = {'oauth_consumer_key' : 'consumer_key',
-                      'oauth_signature_method' : 'PLAINTEXT',
-                      'oauth_signature' : '',
-                      'oauth_timestamp' : str(int(time.time())),
-                      'oauth_nonce' : 'nonce',
-                      'oauth_version' : oauth.OAUTH_VERSION,
-                      'oauth_callback' : 'oob',
+        parameters = {'oauth_consumer_key': 'consumer_key',
+                      'oauth_signature_method': 'PLAINTEXT',
+                      'oauth_signature': '',
+                      'oauth_timestamp': str(int(time.time())),
+                      'oauth_nonce': 'nonce',
+                      'oauth_version': oauth.OAUTH_VERSION,
+                      'oauth_callback': 'oob',
                       }
         response = self.storage.fetch_request_token(parameters)
         self.assertTrue(isinstance(response, OAuthResponse))
-        self.assertEquals(response.token.key, 'request_key')
+        self.assertEqual(response.token.key, 'request_key')
 
     def test_fetch_request_token_compat(self):
         '''Test fetching the request token.'''
-        parameters = {'oauth_consumer_key' : 'consumer_key',
-                      'oauth_signature_method' : 'PLAINTEXT',
-                      'oauth_signature' : '',
-                      'oauth_timestamp' : str(int(time.time())),
-                      'oauth_nonce' : 'nonce',
-                      'oauth_version' : oauth.OAUTH_VERSION,
+        parameters = {'oauth_consumer_key': 'consumer_key',
+                      'oauth_signature_method': 'PLAINTEXT',
+                      'oauth_signature': '',
+                      'oauth_timestamp': str(int(time.time())),
+                      'oauth_nonce': 'nonce',
+                      'oauth_version': oauth.OAUTH_VERSION,
                       }
         response = self.storage.fetch_request_token(parameters)
         self.assertTrue(isinstance(response, OAuthResponse))
-        self.assertEquals(response.token.key, 'request_key')
+        self.assertEqual(response.token.key, 'request_key')
 
     def test_authorize_request_token(self):
         '''Test authorizing a request token.'''

=== added file 'run-tests'
--- run-tests	1970-01-01 00:00:00 +0000
+++ run-tests	2012-05-15 18:53:11 +0000
@@ -0,0 +1,31 @@
+#!/bin/bash
+#
+# Copyright 2010-2012 Canonical Ltd.
+#
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
+#
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
+#
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+# THE SOFTWARE.
+
+set -e -x
+
+# Run the tests with both python (2.x) and python3
+./setup.py build test clean
+python3 ./setup.py build test clean
+
+# Style checks
+pyflakes poauth setup.py
+pep8 --repeat . setup.py

=== modified file 'setup.py'
--- setup.py	2009-08-31 19:20:49 +0000
+++ setup.py	2012-05-15 18:53:11 +0000
@@ -1,9 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/python
 #
 # The MIT License
 #
 # Copyright (c) 2007 Leah Culver
-# Copyright (c) 2009 Canonical, Ltd.
+# Copyright (c) 2009-2012 Canonical, Ltd.
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -34,5 +34,7 @@
     license='MIT',
     author='Rodney Dawes',
     author_email='rodney.dawes@canonical.com',
+    download_url='https://launchpad.net/poauth/+download',
     packages=find_packages(),
+    test_suite='poauth.tests',
 )

